==> ogre-docs-1.11.5-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_sub_mesh.js <==
var class_ogre_1_1_sub_mesh =
[
    [ "IndexMap", "class_ogre_1_1_sub_mesh.html#a77002e2ac2d5f5041e4b0fe3bd228245", null ],
    [ "LODFaceList", "class_ogre_1_1_sub_mesh.html#a75594d10e60849696ca80f4d6cf375f4", null ],
    [ "VertexBoneAssignmentList", "class_ogre_1_1_sub_mesh.html#ab396ad138e9d8b48355d495215989881", null ],
    [ "BoneAssignmentIterator", "class_ogre_1_1_sub_mesh.html#a9c23baff85d3b4f60e37f2a514be1ada", null ],
    [ "AliasTextureIterator", "class_ogre_1_1_sub_mesh.html#a243e656daab531eea35d8b9fb5dc3b11", null ],
    [ "SubMesh", "class_ogre_1_1_sub_mesh.html#aa5e04097716119c5cfed229c8425fc60", null ],
    [ "~SubMesh", "class_ogre_1_1_sub_mesh.html#ad0a51b024271c2042968e9e967dd39e8", null ],
    [ "setMaterialName", "class_ogre_1_1_sub_mesh.html#a8ad6c0cae3c325cd8953ab66bd97e72d", null ],
    [ "getMaterialName", "class_ogre_1_1_sub_mesh.html#a78df2f25365fcf452af62aacd85c83a3", null ],
    [ "isMatInitialised", "class_ogre_1_1_sub_mesh.html#a6c7371d6d8aaa3e8117f26b3be958b44", null ],
    [ "_getRenderOperation", "class_ogre_1_1_sub_mesh.html#a4770787312a616e8735c5d1a864bb1cb", null ],
    [ "addBoneAssignment", "class_ogre_1_1_sub_mesh.html#abdd303710ef1131801f5017ef2eda1f2", null ],
    [ "clearBoneAssignments", "class_ogre_1_1_sub_mesh.html#a2c29dd4601e67d3f6d26d7d74c017995", null ],
    [ "getBoneAssignmentIterator", "class_ogre_1_1_sub_mesh.html#ab37844a411ccea1cf06d1c95e10b71e2", null ],
    [ "getBoneAssignments", "class_ogre_1_1_sub_mesh.html#a03901f7c72762aa3794af16b88c3e196", null ],
    [ "_compileBoneAssignments", "class_ogre_1_1_sub_mesh.html#acd127d162c4271ac6b844161e1ea777a", null ],
    [ "getAliasTextureIterator", "class_ogre_1_1_sub_mesh.html#ab284e1061042026fa872f3b76b701caf", null ],
    [ "addTextureAlias", "class_ogre_1_1_sub_mesh.html#abe04d5342331ad434e47ca9b934a7622", null ],
    [ "removeTextureAlias", "class_ogre_1_1_sub_mesh.html#a9007b549c95c6fb1402818bf55b65b16", null ],
    [ "removeAllTextureAliases", "class_ogre_1_1_sub_mesh.html#a8446f2b030ecd536933c0a39cdb3d61a", null ],
    [ "hasTextureAliases", "class_ogre_1_1_sub_mesh.html#a7277f01fb328b268deffb94b351c5c1d", null ],
    [ "getTextureAliasCount", "class_ogre_1_1_sub_mesh.html#a0aca2c1ed5b5f115e882ea2481bb1769", null ],
    [ "updateMaterialUsingTextureAliases", "class_ogre_1_1_sub_mesh.html#a2107e531c7161b312571d8977f9539e2", null ],
    [ "getVertexAnimationType", "class_ogre_1_1_sub_mesh.html#add91fed2eb2a3330b2004248572642e4", null ],
    [ "getVertexAnimationIncludesNormals", "class_ogre_1_1_sub_mesh.html#af9bf141e65f964f131229501804940e5", null ],
    [ "generateExtremes", "class_ogre_1_1_sub_mesh.html#af32a20ce7dd6ca470ce7e33e5dc7d7d9", null ],
    [ "isBuildEdgesEnabled", "class_ogre_1_1_sub_mesh.html#acae45080848d0e53474aaf11c0ce5209", null ],
    [ "setBuildEdgesEnabled", "class_ogre_1_1_sub_mesh.html#acc667dc8cf61d4fa25f005fd5cb9082a", null ],
    [ "clone", "class_ogre_1_1_sub_mesh.html#a2ec4714cce3f0c922670c038ff95a5b7", null ],
    [ "Mesh", "class_ogre_1_1_sub_mesh.html#aa41a130f156b145bffb3f4b5172c4c93", null ],
    [ "MeshSerializerImpl", "class_ogre_1_1_sub_mesh.html#a48305c54a01e0c7a3376ea0a077c467f", null ],
    [ "MeshSerializerImpl_v1_2", "class_ogre_1_1_sub_mesh.html#ae60e96165c5d5495195fa0d49f031372", null ],
    [ "MeshSerializerImpl_v1_1", "class_ogre_1_1_sub_mesh.html#aef9901d67ded13a151aa3d4fde3a7b17", null ],
    [ "useSharedVertices", "class_ogre_1_1_sub_mesh.html#a931e3764e3bf1c3ef7431fc852770fb1", null ],
    [ "operationType", "class_ogre_1_1_sub_mesh.html#a10ed3ef8bb24a001bb89dc9e3cd88c31", null ],
    [ "vertexData", "class_ogre_1_1_sub_mesh.html#a1862a3ec9a3f2ed4ade8af69b41a809d", null ],
    [ "indexData", "class_ogre_1_1_sub_mesh.html#aad428fa6595c7fb01ef7543e5d8d6454", null ],
    [ "blendIndexToBoneIndexMap", "class_ogre_1_1_sub_mesh.html#ae6b4c1d0724fe6a9a961b73bd646d3cf", null ],
    [ "mLodFaceList", "class_ogre_1_1_sub_mesh.html#a821d2587eb2dc9746a2b1a5c0deada32", null ],
    [ "extremityPoints", "class_ogre_1_1_sub_mesh.html#ac63766998cb839ca582947d7545214f5", null ],
    [ "parent", "class_ogre_1_1_sub_mesh.html#ac2b9fd25eb56625716d9e8915f4e0e7d", null ]
];

==> ogre-docs-1.12.0-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_sub_mesh.js <==
var class_ogre_1_1_sub_mesh =
[
    [ "IndexMap", "class_ogre_1_1_sub_mesh.html#a77002e2ac2d5f5041e4b0fe3bd228245", null ],
    [ "LODFaceList", "class_ogre_1_1_sub_mesh.html#a75594d10e60849696ca80f4d6cf375f4", null ],
    [ "VertexBoneAssignmentList", "class_ogre_1_1_sub_mesh.html#ab396ad138e9d8b48355d495215989881", null ],
    [ "BoneAssignmentIterator", "class_ogre_1_1_sub_mesh.html#a9c23baff85d3b4f60e37f2a514be1ada", null ],
    [ "AliasTextureIterator", "class_ogre_1_1_sub_mesh.html#a243e656daab531eea35d8b9fb5dc3b11", null ],
    [ "SubMesh", "class_ogre_1_1_sub_mesh.html#aa5e04097716119c5cfed229c8425fc60", null ],
    [ "~SubMesh", "class_ogre_1_1_sub_mesh.html#ad0a51b024271c2042968e9e967dd39e8", null ],
    [ "setMaterialName", "class_ogre_1_1_sub_mesh.html#a8ad6c0cae3c325cd8953ab66bd97e72d", null ],
    [ "getMaterialName", "class_ogre_1_1_sub_mesh.html#a78df2f25365fcf452af62aacd85c83a3", null ],
    [ "setMaterial", "class_ogre_1_1_sub_mesh.html#afc7f071088a6ab4dbc0618537deea652", null ],
    [ "getMaterial", "class_ogre_1_1_sub_mesh.html#ac183f5e168bd734c6388589975af155d", null ],
    [ "isMatInitialised", "class_ogre_1_1_sub_mesh.html#a6c7371d6d8aaa3e8117f26b3be958b44", null ],
    [ "_getRenderOperation", "class_ogre_1_1_sub_mesh.html#a4770787312a616e8735c5d1a864bb1cb", null ],
    [ "addBoneAssignment", "class_ogre_1_1_sub_mesh.html#abdd303710ef1131801f5017ef2eda1f2", null ],
    [ "clearBoneAssignments", "class_ogre_1_1_sub_mesh.html#a2c29dd4601e67d3f6d26d7d74c017995", null ],
    [ "getBoneAssignmentIterator", "class_ogre_1_1_sub_mesh.html#ab37844a411ccea1cf06d1c95e10b71e2", null ],
    [ "getBoneAssignments", "class_ogre_1_1_sub_mesh.html#a03901f7c72762aa3794af16b88c3e196", null ],
    [ "_compileBoneAssignments", "class_ogre_1_1_sub_mesh.html#acd127d162c4271ac6b844161e1ea777a", null ],
    [ "getAliasTextureIterator", "class_ogre_1_1_sub_mesh.html#ab284e1061042026fa872f3b76b701caf", null ],
    [ "addTextureAlias", "class_ogre_1_1_sub_mesh.html#abe04d5342331ad434e47ca9b934a7622", null ],
    [ "removeTextureAlias", "class_ogre_1_1_sub_mesh.html#a9007b549c95c6fb1402818bf55b65b16", null ],
    [ "removeAllTextureAliases", "class_ogre_1_1_sub_mesh.html#a8446f2b030ecd536933c0a39cdb3d61a", null ],
    [ "hasTextureAliases", "class_ogre_1_1_sub_mesh.html#a7277f01fb328b268deffb94b351c5c1d", null ],
    [ "getTextureAliasCount", "class_ogre_1_1_sub_mesh.html#a0aca2c1ed5b5f115e882ea2481bb1769", null ],
    [ "updateMaterialUsingTextureAliases", "class_ogre_1_1_sub_mesh.html#a2107e531c7161b312571d8977f9539e2", null ],
    [ "getVertexAnimationType", "class_ogre_1_1_sub_mesh.html#add91fed2eb2a3330b2004248572642e4", null ],
    [ "getVertexAnimationIncludesNormals", "class_ogre_1_1_sub_mesh.html#af9bf141e65f964f131229501804940e5", null ],
    [ "generateExtremes", "class_ogre_1_1_sub_mesh.html#af32a20ce7dd6ca470ce7e33e5dc7d7d9", null ],
    [ "isBuildEdgesEnabled", "class_ogre_1_1_sub_mesh.html#acae45080848d0e53474aaf11c0ce5209", null ],
    [ "setBuildEdgesEnabled", "class_ogre_1_1_sub_mesh.html#acc667dc8cf61d4fa25f005fd5cb9082a", null ],
    [ "clone", "class_ogre_1_1_sub_mesh.html#a2ec4714cce3f0c922670c038ff95a5b7", null ],
    [ "Mesh", "class_ogre_1_1_sub_mesh.html#aa41a130f156b145bffb3f4b5172c4c93", null ],
    [ "MeshSerializerImpl", "class_ogre_1_1_sub_mesh.html#a48305c54a01e0c7a3376ea0a077c467f", null ],
    [ "MeshSerializerImpl_v1_2", "class_ogre_1_1_sub_mesh.html#ae60e96165c5d5495195fa0d49f031372", null ],
    [ "MeshSerializerImpl_v1_1", "class_ogre_1_1_sub_mesh.html#aef9901d67ded13a151aa3d4fde3a7b17", null ],
    [ "useSharedVertices", "class_ogre_1_1_sub_mesh.html#a931e3764e3bf1c3ef7431fc852770fb1", null ],
    [ "operationType", "class_ogre_1_1_sub_mesh.html#a10ed3ef8bb24a001bb89dc9e3cd88c31", null ],
    [ "vertexData", "class_ogre_1_1_sub_mesh.html#a1862a3ec9a3f2ed4ade8af69b41a809d", null ],
    [ "indexData", "class_ogre_1_1_sub_mesh.html#aad428fa6595c7fb01ef7543e5d8d6454", null ],
    [ "blendIndexToBoneIndexMap", "class_ogre_1_1_sub_mesh.html#ae6b4c1d0724fe6a9a961b73bd646d3cf", null ],
    [ "mLodFaceList", "class_ogre_1_1_sub_mesh.html#a821d2587eb2dc9746a2b1a5c0deada32", null ],
    [ "extremityPoints", "class_ogre_1_1_sub_mesh.html#ac63766998cb839ca582947d7545214f5", null ],
    [ "parent", "class_ogre_1_1_sub_mesh.html#ac2b9fd25eb56625716d9e8915f4e0e7d", null ]
];
